# You can now run a GPT-3 level AI model on your laptop, phone, and Raspberry Pi
## Thanks to Meta LLaMA, AI text models have their "Stable Diffusion moment."
## Information:

+ Link: https://arstechnica.com/information-technology/2023/03/you-can-now-run-a-gpt-3-level-ai-model-on-your-laptop-phone-and-raspberry-pi/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 13 March 2023, 23:16
+ Date scraped: 14 March 2023, 00:01

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2023/03/llama_laptop_hero_1-760x380.jpg)







Things are moving at lighting speed in AI Land. On Friday, a software developer named Georgi Gerganov created a tool called ["llama.cpp"](https://github.com/ggerganov/llama.cpp) that can run Meta's new GPT-3-class AI large language model, [LLaMA](https://arstechnica.com/information-technology/2023/02/chatgpt-on-your-pc-meta-unveils-new-ai-model-that-can-run-on-a-single-gpu/), locally on a Mac laptop. Soon thereafter, people worked out [how to run LLaMA on Windows](https://github.com/ggerganov/llama.cpp/issues/22) as well. Then someone [showed in running](https://twitter.com/thiteanish/status/1635188333705043969) on a Pixel 6 phone. Next came [a Raspberry Pi](https://twitter.com/miolini/status/1634982361757790209) (albeit very slowly).


If this keeps up, we may be looking at a pocket-sized [ChatGPT competitor](https://arstechnica.com/information-technology/2023/03/get-ready-to-meet-the-chat-gpt-clones/) before we know it.


But let's back up a minute, because we're not quite there yet. (At least not today—as in literally today, March 13, 2023.) But what will arrive next week, no one knows.


Since [ChatGPT launched](https://arstechnica.com/information-technology/2022/12/openai-invites-everyone-to-test-new-ai-powered-chatbot-with-amusing-results/), some people have been frustrated by the AI model's built-in limits that prevent it from discussing topics that OpenAI has deemed sensitive. Thus began the [dream—](https://boards.4channel.org/g/thread/91848262#p91850335)in some quarters—of an open source large language model (LLM) that anyone could run locally without censorship and without paying [API fees](https://arstechnica.com/information-technology/2023/03/chatgpt-and-whisper-apis-debut-allowing-devs-to-integrate-them-into-apps/) to OpenAI.


Open source solutions do exist (such as [GPT-J](https://www.reddit.com/r/MachineLearning/comments/oe6paj/d_gptj_for_text_generation_hardware_requirements/)), but they [require](https://www.reddit.com/r/MachineLearning/comments/oe6paj/d_gptj_for_text_generation_hardware_requirements/) a lot of GPU RAM and storage space. Other open source alternatives could not boast GPT-3-level performance on readily available consumer-level hardware.


Enter LLaMA, an LLM available in parameter sizes ranging from 7B to 65B (that's "B" as in "billion parameters," which are floating point numbers stored in matrices that represent what the model "knows"). LLaMA made a heady claim: that its smaller-sized models could match [OpenAI's GPT-3](https://arstechnica.com/information-technology/2022/09/twitter-pranksters-derail-gpt-3-bot-with-newly-discovered-prompt-injection-hack/), the foundational model that powers ChatGPT, in the quality and speed of its output. There was just one problem—Meta released the LLaMA code open source, but it held back the "weights" (the trained "knowledge" stored in a neural network) for qualified researchers only.


## Flying at the speed of LLaMA


Meta's restrictions on LLaMA didn't last long, because on March 2, someone [leaked the LLaMA weights](https://news.ycombinator.com/item?id=35007978) on BitTorrent. Since then, there's been an explosion of development surrounding LLaMA. Independent AI researcher Simon Willison has [compared](https://simonwillison.net/2023/Mar/11/llama/) this situation to the release of Stable Diffusion, an open source image synthesis model that launched last August. Here's what he wrote in a post on his blog:



> It feels to me like that Stable Diffusion moment back in August kick-started the entire new wave of interest in generative AI—which was then pushed into over-drive by the release of ChatGPT at the end of November.
> 
> 
> That Stable Diffusion moment is happening again right now, for large language models—the technology behind ChatGPT itself. This morning I ran a GPT-3 class language model on my own personal laptop for the first time!
> 
> 
> AI stuff was weird already. It’s about to get a whole lot weirder.
> 
> 


Typically, running GPT-3 requires several datacenter-class [A100](https://arstechnica.com/gadgets/2020/05/nvidia-ditches-intel-cozies-up-to-amd-with-its-new-dgx-a100/) GPUs (also, the weights for GPT-3 are not public), but LLaMA made waves because it could run on a single beefy consumer GPU. And now, with optimizations that reduce the model size using a technique called quantization, LLaMA can run on an M1 Mac or a lesser Nvidia consumer GPU.


Things are moving so quickly that it's sometimes [difficult to keep up](https://arstechnica.com/information-technology/2022/12/please-slow-down-the-7-biggest-ai-stories-of-2022/) with the latest developments. (Regarding AI's rate of progress, a fellow AI reporter told Ars, "It's like those videos of dogs where you upend a crate of tennis balls on them. [They] don't know where to chase first and get lost in the confusion.")


For example, here's a list of notable LLaMA-related events based on a [timeline](https://news.ycombinator.com/item?id=35140369) Willison laid out in a Hacker News comment:


* February 24, 2023: Meta AI [announces](https://arstechnica.com/information-technology/2023/02/chatgpt-on-your-pc-meta-unveils-new-ai-model-that-can-run-on-a-single-gpu/) LLaMA.
* March 2, 2023: Someone [leaks the LLaMA models](https://news.ycombinator.com/item?id=35007978) via BitTorrent.
* March 10, 2023: Georgi Gerganov [creates llama.cpp](https://github.com/ggerganov/llama.cpp/commit/26c084662903ddaca19bef982831bfb0856e8257), which can run on an M1 Mac.
* March 11, 2023: Artem Andreenko runs LLaMA 7B (slowly) [on a Raspberry Pi 4](https://twitter.com/miolini/status/1634982361757790209), 4GB RAM, 10 sec/token.
* March 12, 2023: LLaMA 7B [running on NPX,](https://cocktailpeanut.github.io/dalai/#/) a node.js execution tool.
* March 13, 2023: Someone gets llama.cpp running [on a Pixel 6 phone](https://twitter.com/thiteanish/status/1635188333705043969), also very slowly.
* March 13, 2023, 2023: Standord releases [Alpaca 7B](https://crfm.stanford.edu/2023/03/13/alpaca.html), an instruction-tuned version of LLaMA 7B that "behaves similarly to OpenAI's "[text-davinci-003](https://arstechnica.com/information-technology/2022/11/openai-conquers-rhyming-poetry-with-new-gpt-3-update/)" but runs on much less powerful hardware.


After obtaining the LLaMA weights ourselves, we followed Willison's instructions and got the 7B parameter version running on an M1 Macbook Air, and it runs at a reasonable rate of speed. You call it as a script on the command line with a prompt, and LLaMA does its best to complete it in a reasonable way.


[![A screenshot of LLaMA 7B in action on a MacBook Air running llama.cpp.](https://cdn.arstechnica.net/wp-content/uploads/2023/03/llama_mac_screenshot-640x400.png)](https://cdn.arstechnica.net/wp-content/uploads/2023/03/llama_mac_screenshot.png) / A screenshot of LLaMA 7B in action on a MacBook Air running llama.cpp.Benj Edwards / Ars Technica


There's still the question of how much the quantization affects the quality of the output. In our tests, LLaMA 7B trimmed down to 4-bit quantization was very impressive for running on a MacBook Air—but still not on par with what you might expect from ChatGPT. It's entirely possible that better prompting techniques might generate better results.


Also, optimizations and fine-tunings come quickly when everyone has their hands on the code and the weights—even though LLaMA is still saddled with some [fairly restrictive](https://docs.google.com/forms/d/e/1FAIpQLSfqNECQnMkycAp2jP4Z9TFX0cGR4uf7b_fBxjY_OjhJILlKGA/viewform) terms of use. The [release of Alpaca](https://crfm.stanford.edu/2023/03/13/alpaca.html) today by Stanford proves that fine tuning (additional training with a specific goal in mind) can improve performance, and it's still early days after LLaMA's release.


As of this writing, running LLaMA on a Mac remains a fairly technical exercise. You have to install Python and Xcode and be familiar with working on the command line. Willison has good [step-by-step instructions](https://simonwillison.net/2023/Mar/11/llama/) for anyone who would like to attempt it. But that may soon change as developers continue to code away.


As for the implications of having this tech out in the wild—no one knows yet. While some worry about AI's impact as a tool for spam and misinformation, Willison says, "It’s not going to be un-invented, so I think our priority should be figuring out the most constructive possible ways to use it."


Right now, our only guarantee is that things will change rapidly.














## Tags:


### Autogenerated tags:
7b chatgpt willison openai gpt-3 llama.cpp gpu m1 macbook
