# Einstein tilings – the amazing “Hat” shape that never repeats!
## Imagine tiling a whole football field using a single shape… yet not being able to produce a repeating pattern, even if you wanted to.
## Information:

+ Link: https://nakedsecurity.sophos.com/2023/04/04/einstein-tilings-the-amazing-hat-shape-that-never-repeats/
+ Source: Naked Security
+ Author: Paul Ducklin
+ Date published: 04 April 2023, 18:59
+ Date scraped: 05 April 2023, 17:00

## Article:
![Main article image](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2023/04/hat-1200.png?w=775)


Mathematics is a complex and esoteric field that underpins science and engineering, notably including the disciplines of cryptography and cybersecurity.


(There… we’ve added a mention of cybersecurity, thus justifying the rest of this article.)


The topic of mathematics has been extensively and fervently studied from at least ancient Babylonian times, and the names of many famous mathematicians have entered our everyday vocabulary, in phrases such as *Pythagorean* triangles (those that have a right angle in them), *Cartesian* geometry (working with shapes on a flat surfaces), computer *algorithms* (instruction sequences that work iteratively or recuersively to compute a result), and *Penrose* tilings.


Penrose tilings, if you’ve ever met them, were figured out by Sir Roger Penrose in the 1970s, and dealt with fascinating and unusual ways of covering surfaces in combinations of shapes.


In case you’re wondering why the word *algorithm* doesn’t have a capital letter like the others, that’s because it’s not a precise rendering of an original name, but a word derived from *Muhammad ibn Musa al-Khwarizmi*, an influential mathematician, geographer and astronomer who lived about 1200 years ago in an area to east of the Caspian Sea and south of the Aral Sea, a region now split between Uzbekistan and Turkmenistan.


## Tiling made funky


Tiled surfaces, of course, are common, for example in bathrooms, kitchens and walkways.


And on roofs, of course, but we’ll ignore roofing tiles in this article because they’re designed to overlap, so they keep rain out without needing to be individually sealed against one another.


Even carpeted areas are often tiled, especially in offices, so that parts of the floor can be re-tiled without ripping up and replacing the lightly used carpeting around the worn-out parts.


If you’ve ever visited Sophos HQ in the UK, for example you’ll know that it’s a largely open-plan area that is covered in square carpet tiles in various gentle shades of blue and light green:


![](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2023/04/carpet-640.png)


As you can see, square tiles form what’s known as a *periodic pattern*, meaning that the pattern repeats itself every so often.


In the example above, the precise grid used in the layout ensures that the pattern repeats itself in both dimensions after moving just one square up, down, left or right.


More complex and visually appealing patterns, which are nevertheless periodic tilings because they keep repeating, can be made with regular combinations of simple shapes, such as the hepta-pentagon:


![](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2023/04/heptapet-640.png)


Or the rhombi-tri-hexagon:


![](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2023/04/rhomitrihex-640.png)


## Penrose tilings


That brings us to Penrose tilings.


Although Sir Roger Penrose is probably most famous as the winner of the Nobel Prize for Physics in 2020, he is also renowned for his work into s special class of tile patterns known as known *aperiodic tilings*.


Unlike periodic tilings, which repeat every so often, aperiodic tilings never repeat, no matter how carefully you choose the next piece to place, and where to place it…


…even though the tilings are based on a finite number of shapes, and cover an infinte surface without any gaps or overlaps.


Periodic tilings are a bit like rational numbers (fractions based on one integer divided by another), in that eventually they repeat no matter what you do.


If you divide 22 by 7, for example, you get about 3.142.., usefully close to the value of Pi, which is about 3.14159…


But 22/7 actually comes out as 3.142857142857142857… and that pattern 142857 keeps repeating forever, because the number is the ratio (thus the description *rational number*) of two whole numbers.


In contrast, the true value of Pi is *irrational*: it can’t be reduced to a ratio, and its value in decimal never falls into a repeating pattern.


What about a similar sort of never-repeating sequence based not on numerical values but on shapes?


Would you need an infinite number of different shapes to guarantee a pattern that never repeated, or could you get your (admittedly never-ending) tiling job done with a finite set of tiles?


Penrose got the number of different shapes needed to guarantee non-repeating tilings down to just two, but the question has lingered ever since: **Can you find a single shape, a single tile, that can be laid down repeatedly to cover an infinite surface without ever repeating?**


In what passes as a mathematical pun, this Holy Grail of tiles is known as an *einstein*, which means “one shape” in German, but also echoes the name Albert Einstein, of E=mc2 fame.


## Introducing… the Hat


Well, a mathematical foursome spearheaded by a British shape-searcher called David Smith, claims that einsteins do exist, and have revealed a triskaidecagon (that’s a 13-sided figure) that they’ve dubbed the **Hat**.


They claim they’ve proved that the Hat generates the long-sought-after outcome of an aperiodic pattern, all on its own:


![](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2023/04/hat-640.png)


Simply put, if you tile your floor, or your porch, or your driveway, or even the local football pitch with a supply of Hat tiles…


…you’ll eventually cover the whole surface with a pattern than never actually repeats.


For all that it displays various “sub-designs” and apparent self-similarities as you construct your Hat-based artwork, this is the Pi of floor tiles: try as you will, you’ll never get a regular, periodic pattern out of it.


## What to do?


We’re not going even to attempt a description of the [proof](https://arxiv.org/pdf/2303.10798.pdf) here – in all honesty, we haven’t yet managed to digest it ourselves – so we shall merely suggest that you [study it](https://arxiv.org/pdf/2303.10798.pdf) in your own time. (Perhaps set aside a long weekend for the task?


But if you want to play with the concept of aperiodic tilings, why not bake yourself some Hat biscuits, or cookies if you’re from North America?


If you’ve got a 3D printer, you can download a design to make your very own Hat-shaped pastry cutter!






---





## Tags:


### Autogenerated tags:
penrose
